@@ -6,8 +6,8 @@
 ;; URL: https://github.com/abougouffa/one-tab-per-project
 ;; Created: July 07, 2024
 ;; Modified: June 15, 2025
-;; Package-Version: 3.4.0
-;; Package-Revision: f6d2f021ebfb
+;; Package-Version: 3.4.1
+;; Package-Revision: 2c5bfb6ef06d
 ;; Package-Requires: ((emacs "28.1") (compat "29.1"))
 ;; Keywords: convenience
 ;; SPDX-License-Identifier: GPL-3.0
@@ -722,8 +722,7 @@ Calls ORIG-FN with ARGS."
         ;; Rename the first tab to default name if needed
         (otpp--set-default-tab-name)
         (add-hook 'server-after-make-frame-hook #'otpp--set-default-tab-name))
-    (when otpp-find-file-integration
-      (advice-remove 'find-file #'otpp--find-file-a))
+    (advice-remove 'find-file #'otpp--find-file-a)
     (advice-remove 'kill-buffer #'otpp--bury-on-kill-buffer-in-multiple-tabs-a)
     (remove-hook 'server-after-make-frame-hook #'otpp--set-default-tab-name)))
 
